Enum Stat
#[repr(u8)]pub enum Stat {
Disabled = 0,
Stall = 1,
Nak = 2,
Valid = 3,
}Variants
Disabled = 0
all requests addressed to this endpoint are ignored
Stall = 1
the endpoint is stalled and all requests result in a STALL handshake
Nak = 2
the endpoint is naked and all requests result in a NAK handshake
Valid = 3
this endpoint is enabled, requests are ACKed
Implementations